==> portal-contribuinte-3.248.0.zip: BOOT-INF/classes/sql/simam/conferencia/EstornoArrecadacaoPorTipoCredito.sql <==
select 14                                                        as codigoArquivo,
       'Estorno de Arrecadação por Tipo de Crédito'              as arquivo,
       'DEBITO'                                                  as tipoArquivo,
       arquivo.valor                                             as valorArquivo,
       integracao.valor                                          as valorIntegracao,
       retencao.valor                                            as valorRetencao,
       (select
        case when count(teis.idregistro) > 0 then 'true' else 'false' end
        from tcearrecadacaotipocreditoest tatce
        join triberrosimportacaosimam teis on
        teis.idregistro = tatce.idtcearrtipocreditoest
        and teis.identificadorarquivo = 'ESTORNO_ARRECADACAO_TIPO_CREDITO'
        where tatce.nrmes = :mes and tatce.nrano = :ano) as temerroimportacao
from (select sum(valor) as valor
      from (SELECT sum(coalesce(tatce.vlestorno, 0)) as valor
            FROM tceArrecadacaoTipoCreditoEst tatce
            WHERE tatce.nrmes = :mes and tatce.nrano = :ano) dados) arquivo
         cross join (select sum(liic.valortributo - liic.valordeducao) as valor
                     from loteintegracaocontabil lic
                              left join loteitemintegracaocontabil liic
                                        on lic.id = liic.idlote
                              left join tribreceita tr on liic.idtributo = tr.id
                              left JOIN tribreceitatipo trt ON trt.tiporeceita = tr.tiporeceita
                     where lic.datalote between :dataInicial and :dataFinal
                       and trt.classificacaoreceitatipo IN (1, 2, 3, 4, 5, 7)
                       and lic.situacaointegracaocontabil != 'ESTORNADO_CONTABILIDADE'
                       and liic.idtipooperacaodeducao != 3
                       and lic.tipolote = 'ESTORNO_PAGAMENTO') integracao
         cross join (select coalesce(sum(rc.valor),0) as valor from tceretencaocontabil rc
                     where rc.dtlancamento between :dataInicial and :dataFinal and rc.devolucao = 'S') retencao

==> portal-contribuinte-3.326.0.zip: BOOT-INF/classes/sql/simam/conferencia/EstornoArrecadacaoPorTipoCredito.sql <==
select 14                                                        as codigoArquivo,
       'Estorno de Arrecadação por Tipo de Crédito'              as arquivo,
       'DEBITO'                                                  as tipoArquivo,
       arquivo.valor                                             as valorArquivo,
       integracao.valor                                          as valorIntegracao,
       retencao.valor                                            as valorRetencao,
       (select
        case when count(teis.idregistro) > 0 then 'true' else 'false' end
        from tcearrecadacaotipocreditoest tatce
        join triberrosimportacaosimam teis on
        teis.idregistro = tatce.idtcearrtipocreditoest
        and teis.identificadorarquivo = 'ESTORNO_ARRECADACAO_TIPO_CREDITO'
        where tatce.nrmes = :mes and tatce.nrano = :ano) as temerroimportacao,
                                                                                     'false' as temerronrcreditodivida
from (select sum(valor) as valor
      from (SELECT sum(coalesce(tatce.vlestorno, 0)) as valor
            FROM tceArrecadacaoTipoCreditoEst tatce
            WHERE tatce.nrmes = :mes and tatce.nrano = :ano) dados) arquivo
         cross join (select sum(liic.valortributo - liic.valordeducao) as valor
                     from loteintegracaocontabil lic
                              left join loteitemintegracaocontabil liic
                                        on lic.id = liic.idlote
                              left join tribreceita tr on liic.idtributo = tr.id
                              left JOIN tribreceitatipo trt ON trt.tiporeceita = tr.tiporeceita
                     where lic.datalote between :dataInicial and :dataFinal
                       and trt.classificacaoreceitatipo IN (1, 2, 3, 4, 5, 7)
                       and lic.situacaointegracaocontabil != 'ESTORNADO_CONTABILIDADE'
                       and liic.idtipooperacaodeducao != 3
                       and lic.tipolote = 'ESTORNO_PAGAMENTO') integracao
         cross join (select coalesce(sum(rc.valor),0) as valor from tceretencaocontabil rc
                     where rc.dtlancamento between :dataInicial and :dataFinal and rc.devolucao = 'S') retencao
